"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getJSXElementName = void 0;
const types_1 = require("@babel/types");
/**
 * Get the name of a JXS Element
 *
 * @remarks
 *
 * Valid JSX:
 *
 * <MyComponent />
 * <A.MyComponent />
 * <B.A.MyComponent />
 * <C.B.A.MyComponent />
 * ..etc
 *
 * @privateRemarks
 *
 * This was abstracted as it needs to be recursive
 *
 */
function getJSXElementName(node) {
    return getElementName(node.name);
}
exports.getJSXElementName = getJSXElementName;
/**
 * Recursive helper function for getJSXElementName
 */
function getElementName(node) {
    if ((0, types_1.isJSXIdentifier)(node)) {
        return node.name;
    }
    else if ((0, types_1.isJSXNamespacedName)(node)) {
        return node.name.name;
    }
    else {
        return getElementName(node.object);
    }
}
