"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.withPlatformTheme = void 0;
const resolveConfig_1 = __importDefault(require("tailwindcss/resolveConfig"));
function withPlatformTheme(tailwindConfig, { previewCss = false } = {}) {
    const config = (0, resolveConfig_1.default)(tailwindConfig);
    if (!config.theme)
        return config;
    const extendTheme = {};
    function resolvePlatformThemes(key, value, root = extendTheme) {
        var _a;
        if (typeof value !== "object")
            return;
        if (value === null)
            return;
        if (hasPlatformKeys(value)) {
            if (previewCss) {
                root[key] =
                    value.web ||
                        value.default;
            }
            else {
                const platformParameter = Object.entries(value)
                    .map((entry) => entry.join(":"))
                    .join(" ");
                root[key] = `platform(${platformParameter})`;
            }
        }
        else {
            (_a = root[key]) !== null && _a !== void 0 ? _a : (root[key] = {});
            for (const [valueKey, valueValue] of Object.entries(value)) {
                resolvePlatformThemes(valueKey, valueValue, root[key]);
            }
        }
    }
    for (const [key, value] of Object.entries(config.theme)) {
        resolvePlatformThemes(key, value);
    }
    config.theme.extend = extendTheme;
    return config;
}
exports.withPlatformTheme = withPlatformTheme;
function hasPlatformKeys(themeObject) {
    return ("ios" in themeObject ||
        "android" in themeObject ||
        "web" in themeObject ||
        "windows" in themeObject ||
        "macos" in themeObject);
}
